pub enum MapError {
MapTileCacheError(MapTileCacheError),
ZoomFitError(ZoomFitError),
MapTileCropError,
MapCoordinateError,
NoOverlapError,
NoGridCoordinatesForRegion(RegionName),
RegionNameToGridCoordinateCacheError(CacheError),
SplineError(SplineError),
}Expand description
represents errors that can occur while creating a map
Variants
MapTileCacheError(MapTileCacheError)
an error in the map tile cache
ZoomFitError(ZoomFitError)
an error occurred when trying to calculate the zoom level that fits the map grid rectangle into the output image
MapTileCropError
failed to crop a map tile to the required size
MapCoordinateError
failed to calculate pixel coordinates where we want to place a map tile crop
NoOverlapError
no overlap between map tile we fetched and output map (should not happen)
NoGridCoordinatesForRegion(RegionName)
no grid coordinates were returned for one of the region names in the USB Notecard
RegionNameToGridCoordinateCacheError(CacheError)
error in region name to grid coordinate cache
SplineError(SplineError)
error calculating spline