pub enum MapTileCacheEntryStatus {
Missing,
Invalid,
Valid,
}Expand description
status of a cache entry on disk
Variants
Missing
no files at all related to a map tile in the cache
Invalid
an incomplete set of files related to a map tile in the cache
Valid
a usable set of files related to a map tile in the cache (cache policy + either a map tile or an absence marker)