pub enum MapTileCacheError {
CacheDirectoryFileError(Error),
ReqwestError(Error),
HttpError(String, StatusCode, HeaderMap, String),
FailedToCloneRequest,
ImageFormatGuessError(Error),
ImageError(ImageError),
CachePolicyJsonDecodeError(Error),
ZoomLevelError(ZoomLevelError),
CachePolicyError,
}Expand description
errors that can happen while fetching a map tile from the cache
Variants
CacheDirectoryFileError(Error)
error manipulating files in the cache directory
ReqwestError(Error)
reqwest error when fetching the map tile from the server
HttpError(String, StatusCode, HeaderMap, String)
HTTP request is not success
FailedToCloneRequest
failed to clone request for cache policy use (which should not happen unless the body is a stream which it is not for us)
ImageFormatGuessError(Error)
error guessing image format
ImageError(ImageError)
error reading the raw map tile into an image
CachePolicyJsonDecodeError(Error)
error decoding the JSON serialized CachePolicy
ZoomLevelError(ZoomLevelError)
error creating a zoom level
CachePolicyError
error when trying to load cache policy that we previously checked existed on disk