pub enum GridCoordinatesToRegionNameError {
Http(Error),
FailedToCloneRequest,
UnexpectedPrefix(String),
UnexpectedSuffix(String),
RegionName(String, RegionNameError),
}Expand description
Represents the possible errors that can occur when converting grid coordinates to a region name
Variants
Http(Error)
HTTP error
FailedToCloneRequest
failed to clone request for creation of cache policy
UnexpectedPrefix(String)
Unexpected prefix in response body
UnexpectedSuffix(String)
Unexpected suffix in response body
RegionName(String, RegionNameError)
error parsing the region name