pub enum RegionNameToGridCoordinatesError {
Http(Error),
FailedToCloneRequest,
UnexpectedPrefix(String),
UnexpectedSuffix(String),
UnexpectedInfix(String),
X(String, ParseIntError),
Y(String, ParseIntError),
}Expand description
Represents the possible errors that can occur when converting a region name to grid coordinates
Variants
Http(Error)
HTTP error
FailedToCloneRequest
failed to clone request for creation of cache policy
UnexpectedPrefix(String)
Unexpected prefix in response body
UnexpectedSuffix(String)
Unexpected suffix in response body
UnexpectedInfix(String)
Unexpected infix in response body
X(String, ParseIntError)
error parsing the X coordinate
Y(String, ParseIntError)
error parsing the Y coordinate