pub enum USBNotecardToGridRectangleError {
NoUSBNotecardWaypoints,
CacheError(CacheError),
NoGridCoordinatesForRegion(RegionName),
}Expand description
errors that can occur when converting a USB notecard to a grid rectangle
Variants
NoUSBNotecardWaypoints
there were no waypoints in the USB notecards so we could not determine a grid rectangle for it
CacheError(CacheError)
there were errors when converting region names to grid coordinates
NoGridCoordinatesForRegion(RegionName)
no grid coordinates were returned for one of the region names in the USB Notecard