pub struct Map { /* private fields */ }Expand description
represents a map assembled from map tiles
Implementations
Sourceimpl Map
impl Map
Sourcepub async fn new(
map_tile_cache: &mut MapTileCache,
x: u32,
y: u32,
grid_rectangle: GridRectangle,
fill_missing_map_tiles: Option<Rgba<u8>>,
fill_missing_regions: Option<Rgba<u8>>,
) -> Result<Self, MapError>
pub async fn new( map_tile_cache: &mut MapTileCache, x: u32, y: u32, grid_rectangle: GridRectangle, fill_missing_map_tiles: Option<Rgba<u8>>, fill_missing_regions: Option<Rgba<u8>>, ) -> Result<Self, MapError>
creates a new Map
if we choose not to fill the missing map tiles they appear as black
if we choose not to fill the missing regions they appear in a color similar to water but filling them in has some performance impact since we need to check if the region exists by fetching higher resolution map tiles for it.
Errors
returns an error if fetching the map tiles fails
Arguments
map_tile_cache- the map tile cache to use to fetch the map tilesx- the width of the map in pixelsy- the height of the map in pixelsgrid_rectangle- the grid rectangle of regions represented by this map
Sourcepub async fn draw_route(
&mut self,
region_name_to_grid_coordinates_cache: &mut RegionNameToGridCoordinatesCache,
usb_notecard: &USBNotecard,
color: Rgba<u8>,
) -> Result<(), MapError>
pub async fn draw_route( &mut self, region_name_to_grid_coordinates_cache: &mut RegionNameToGridCoordinatesCache, usb_notecard: &USBNotecard, color: Rgba<u8>, ) -> Result<(), MapError>
draws a route from a USBNotecard onto the map
Errors
fails if the region name to grid coordinate conversion fails or the conversion of those into pixel coordinates