pub struct MapTileCache { /* private fields */ }Expand description
a cache for map tiles on the local filesystem
Implementations
Sourceimpl MapTileCache
impl MapTileCache
Sourcepub fn new(cache_directory: PathBuf, ratelimiter: Option<Ratelimiter>) -> Self
pub fn new(cache_directory: PathBuf, ratelimiter: Option<Ratelimiter>) -> Self
creates a new MapTileCache
Sourcepub async fn get_map_tile(
&mut self,
map_tile_descriptor: &MapTileDescriptor,
) -> Result<Option<MapTile>, MapTileCacheError>
pub async fn get_map_tile( &mut self, map_tile_descriptor: &MapTileDescriptor, ) -> Result<Option<MapTile>, MapTileCacheError>
fetches a map tile from the Second Life main map servers or the local cache
Errors
returns an error if the HTTP request fails of if the result fails to be parsed as an image
Sourcepub async fn does_map_tile_exist(
&mut self,
map_tile_descriptor: &MapTileDescriptor,
) -> Result<bool, MapTileCacheError>
pub async fn does_map_tile_exist( &mut self, map_tile_descriptor: &MapTileDescriptor, ) -> Result<bool, MapTileCacheError>
figures out if a map tile exist by checking the local in-memory and disk caches or fetching the map tile from the server
Errors
returns an error if fetching the map tile from cache or remotely fails
Sourcepub async fn does_region_exist(
&mut self,
grid_coordinates: &GridCoordinates,
) -> Result<bool, MapTileCacheError>
pub async fn does_region_exist( &mut self, grid_coordinates: &GridCoordinates, ) -> Result<bool, MapTileCacheError>
figures out if a region exists based on the existence of map tiles for it, starting with the lowest zoom level and potentially going up to the highest one if all the other zoom levels have a tile for that region
Errors
returns an error if fetching map tiles from cache or remotely fails